# Copyright (C) 2014 - 2018  Jack O. Wasey
#
# This file is part of icd.
#
# icd is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# icd is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with icd. If not, see <http:#www.gnu.org/licenses/>.

context("function examples")

# this is essentially duplicated by R CMD check, which runs the examples, but
# doing this here allows test coverage to include more code, and perhaps to make
# sure there are no warnings thrown.

old_opts <- options(warn = 2)
on.exit(options(old_opts), add = TRUE)

testthat::test_examples()
